import QtQuick 2.9
import QtQuick.Layouts 1.15
import org.kde.plasma.core 2.1
import QtQuick.Controls 2.15
import QtWebEngine 1.5

Item {
    id: fullRepresentation

    width: 470
    implicitHeight:  viewHeight
    property var viewHeight:parseInt(iconCode.height+summary.height+story.height+140+radar.height)

    Text {
        id:lastUpdate
        text:"Last update: "+owm.last_update+"\n"+owm.url1
        color:"gray"
        font.pointSize:10
        anchors.top:fullRepresentation.top
        anchors.right:fullRepresentation.right


        MouseArea {
            id: updatemouseArea
            anchors.fill: parent
            cursorShape: Qt.PointingHandCursor
            hoverEnabled:true
            onEntered: lastUpdate.color=Theme.viewHoverColor
            onExited:lastUpdate.color=Theme.viewTextColor
            onClicked: {
                owm.getWeather(owm.url2)
                owm.timerUpdateWeather.restart()
            }
        }
    }
    Row {
        id:conditions
        anchors.top:fullRepresentation.top
        anchors.left:fullRepresentation.left
        spacing:10

        Image {
            id:iconCode
            source:"../icons/"+owm.weatherData.current.weather[0].icon+".png"
            width:64
            height:64
            anchors.topMargin:10
            anchors.top:conditions.top
        }

        Text {
            id:temp
            anchors.top:conditions.top
            anchors.topMargin:20
            text:Math.round(owm.weatherData.current.temp)+"°  "
            color:Theme.viewTextColor
            font.pointSize:24
        }

        Text {
            id:summary
            anchors.top:conditions.top
            anchors.topMargin:30
            //anchors.leftMargin:40
            leftPadding:10
            text:owm.desc//+owm.weatherData.current.weather[0].description
            font.capitalization: Font.Capitalize
            color:Theme.viewTextColor
            font.pointSize:16
        }
    }

    Text {
        id:story
        anchors.top:conditions.bottom
        //leftPadding:20
        anchors.left:conditions.left
        anchors.leftMargin:owm.warnings ? 155:80
        text:owm.warnings ? owm.alert_text : "RealFeel: "+Math.round(owm.weatherData.current.feels_like)+"° "+" Humidity: "+ owm.weatherData.current.humidity+"% "+" Wind "+owm.degToCompass(owm.weatherData.current.wind_deg)+" at "+Math.round(owm.weatherData.current.wind_speed)+owm.formatSpeed()
        wrapMode:Text.WordWrap
        anchors.topMargin:10
        textFormat: Text.RichText
        Layout.fillWidth : true
        width:390
        color:Theme.viewTextColor
        font.pointSize:12

        MouseArea {
            id: mouseArea
            anchors.fill: parent
            cursorShape: owm.warnings ? Qt.PointingHandCursor : Qt.ArrowCursor
            hoverEnabled: owm.warnings ? true : false
            onEntered:owm.warnings ? story.color=Theme.viewHoverColor: story.color=Theme.viewTextColor
            onExited:owm.warnings ? story.color=Theme.viewTextColor : story.color=Theme.viewTextColor
            onClicked: {
                //Qt.openUrlExternally(owm.weatherData.alerts[0].uri)
                forecast.visible=false
                alerts.visible=true

            }
        }
    }

    Rectangle {
        id:ts
        anchors.top:story.bottom
        anchors.topMargin:10
        implicitWidth: fullRepresentation.width
        implicitHeight: 1
        color: "gray"
        antialiasing : true
        Layout.fillWidth: true
    }
    Item {
        id:alerts
        anchors.top:ts.bottom
        visible:false

        Text {
            id:fc
            text:"\t\tBack to Forecast"
            color:Theme.viewTextColor
            leftPadding:20
            font.pointSize:12

            MouseArea {
                id: mouseArea1
                anchors.fill: parent
                cursorShape: Qt.PointingHandCursor
                hoverEnabled:true
                onEntered:fc.color=Theme.viewHoverColor
                onExited:fc.color=Theme.viewTextColor
                onClicked: {
                    //Qt.openUrlExternally(owm.weatherData.alerts[0].uri)
                    forecast.visible=true
                        alerts.visible=false

                }
            }
        }

        ScrollView {
            id: view
            //anchors.fill: parent
            anchors.top:fc.bottom
            width: 500
            height: 110
            clip: true
            ScrollBar.vertical.policy: ScrollBar.AlwaysOn

            TextArea {
                text:"\t\t"+owm.weatherData.alerts[0].event+"\n"+owm.weatherData.alerts[0].description
                Layout.fillWidth : true
                width:500
                wrapMode:Text.WordWrap
                color:Theme.viewTextColor
                leftPadding:20
                font.pointSize:12
            }
        }
    }

    Column {
        id:forecast
        anchors.top:ts.bottom
        anchors.horizontalCenter:fullRepresentation.horizontalCenter
        topPadding:5
        visible:true


        Row {
            id:days
            spacing:50;
            leftPadding:5;
            Repeater {
                model: 5
                Text {
                    text:Qt.formatDate(new Date(owm.weatherData.daily[index].dt*1000)," ddd ")
                    color:Theme.viewTextColor
                    font.pointSize:14

                    Image {
                        source:"../icons/"+owm.weatherData.daily[index].weather[0].icon+".png"
                        anchors.top:parent.bottom
                        anchors.horizontalCenter:parent.horizontalCenter
                        width:48
                        height:48

                        Text {
                            text:Math.round(owm.weatherData.daily[index].pop)*100+"% "
                            color:Theme.viewTextColor
                            anchors.top:parent.bottom
                            anchors.horizontalCenter:parent.horizontalCenter
                            font.pointSize:12

                            Text {
                                text: Math.round(owm.weatherData.daily[index].temp.min)+"°"+"|"+Math.round(owm.weatherData.daily[index].temp.max)+"°"
                                color:Theme.viewTextColor
                                anchors.top:parent.bottom
                                anchors.horizontalCenter:parent.horizontalCenter
                                font.pointSize:12
                            }
                        }
                    }
                }
            }
        }
    }

    Rectangle {
        id:ts1
        anchors.top:forecast.bottom
        anchors.topMargin:120
        implicitWidth: fullRepresentation.width
        implicitHeight: 1
        color: "gray"
        antialiasing : true
        Layout.fillWidth: true
    }


    Item {
        id:radarMap
        //width: imageWidth
        implicitWidth: fullRepresentation.width
        implicitHeight: 370
        anchors.top:ts1.bottom
        anchors.left:ts1.left
        anchors.topMargin:10
        clip:true
        //height: 400
        WebEngineView {
            anchors.fill: radarMap
            anchors.topMargin:-65
            //url: "https://openweathermap.org/weathermap?basemap=map&lang=en&cities=false&layer=radar&lat=29.6915&lon=-95.0474&zoom=6"
            url:"https://openweathermap.org/weathermap?basemap=map&lang=en&cities=false&layer=radar&"+owm.geoLocation+"&zoom=6"
            profile:  WebEngineProfile{
                //httpUserAgent: "Mozilla/5.0 (X11; Linux x86_64; rv:100.0) Gecko/20100101 Firefox/100.0"
                httpUserAgent:"Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/102.0.5005.63 Safari/537.36"
                httpAcceptLanguage : "en-US,en;q=0.5"
                persistentCookiesPolicy :NoPersistentCookies// ForcePersistentCookies
                //NoPersistentCookies //
            }
            onFeaturePermissionRequested: {
                grantFeaturePermission(securityOrigin, feature, true);
                //grantFeaturePermission(cookie, feature, false);
            }
        }
    }
}
