import QtQuick 2.9
import QtQuick.Layouts 1.5
import org.kde.plasma.core 2.1
import QtGraphicalEffects 1.15
import QtQuick.Controls 2.15

Item {
    id: fullRepresentation
    width: 420
    height:470

    Text {
        id:lastUpdate
        text:"Last update: "+ owm.lastUpdate
        color:"gray"
        antialiasing : true
        font.pointSize:9
        anchors.top:fullRepresentation.top
        anchors.right:fullRepresentation.right


        MouseArea {
            id: updatemouseArea
            anchors.fill: parent
            cursorShape: Qt.PointingHandCursor
            hoverEnabled:true
            onEntered: lastUpdate.color=Theme.viewHoverColor
            onExited:lastUpdate.color=Theme.viewTextColor
            onClicked: {
                owm.getWeather(owm.url1)
                owm.radarImage="";
                owm.radarImage="https://cdns.abclocal.go.com/three/ktrk/weatherData/16_9/SETX1_1280.jpg";
                owm.updateWeatherTimer.restart()
            }
        }
    }
    Row {
        id:conditions
        anchors.top:fullRepresentation.top
        anchors.left:fullRepresentation.left
        anchors.topMargin:10
        anchors.leftMargin:20
        spacing:10
        height:64

        Image {
            id:icon
            source:"../icons/"+owm.weatherIcon+".png"
            width:64
            height:64
            smooth:true
        }

        Text {
            id:temp
            text:"  "+owm.currentConditions
            color:Theme.viewTextColor
            font.capitalization: Font.Capitalize
            font.pointSize:16
            antialiasing : true
        }
    }

        Text {
            id:summary
            anchors.bottom:conditions.bottom
            anchors.left:conditions.left
            anchors.topMargin:20
            anchors.leftMargin:80
            text:owm.weatherWarnings ? owm.alertText : owm.weatherSummary
            // if owm.weatherData alert show that instead of summary
            color:Theme.viewTextColor
            font.pointSize:12
            antialiasing : true

             MouseArea {
                id: mouseArea
                anchors.fill: parent
                cursorShape: owm.weatherWarnings ? Qt.PointingHandCursor : Qt.ArrowCursor
                hoverEnabled: owm.weatherWarnings ? true : false
                onEntered:owm.weatherWarnings ? summary.color=Theme.viewHoverColor: summary.color=Theme.viewTextColor
                onExited:owm.weatherWarnings ? summary.color=Theme.viewTextColor : summary.color=Theme.viewTextColor
                onClicked: {
                //Qt.openUrlExternally(owm.weatherDataData.alerts[0].uri)
                forecast.visible=false
                alerts.visible=true

                }
            }
        }

    Rectangle {
            id:ts
            anchors.top:summary.bottom
            anchors.topMargin:10
            anchors.horizontalCenter:fullRepresentation.horizontalCenter
            implicitWidth: fullRepresentation.width*.95
            implicitHeight: .5
            color: "#5b565d"
            antialiasing : true
            Layout.fillWidth: true
        }

    Item {
        id:alerts
        anchors.top:ts.bottom
        visible:false

        Text {
            id:fc
            text:"\t\tBack to Forecast"
            color:Theme.viewTextColor
            leftPadding:20
            font.pointSize:12

            MouseArea {
                id: mouseArea1
                anchors.fill: parent
                cursorShape: Qt.PointingHandCursor
                hoverEnabled:true
                onEntered:fc.color=Theme.viewHoverColor
                onExited:fc.color=Theme.viewTextColor
                onClicked: {
                //Qt.openUrlExternally(owm.weatherDataData.alerts[0].uri)
                forecast.visible=true
                alerts.visible=false

                }
            }
        }

        ScrollView {
        id: view
        //anchors.fill: parent
        anchors.top:fc.bottom
        width: 500
        height: 110
        clip: true
        ScrollBar.vertical.policy: ScrollBar.AlwaysOn

    TextArea {
            text:"\t\t"+owm.alertText+"\n"+owm.alertDesc
            Layout.fillWidth : true
            width:500
            wrapMode:Text.WordWrap
            color:Theme.viewTextColor
            leftPadding:20
            font.pointSize:12
    }
}
}

    Rectangle {
        id:ts1
        anchors.top:summary.bottom
        anchors.topMargin:10
        implicitWidth: fullRepresentation.width*.95
        anchors.horizontalCenter:fullRepresentation.horizontalCenter
        implicitHeight: .5
        radius:8
        color: "#5b565d"
        antialiasing : true
        Layout.fillWidth: false
    }

    Row {
        id:forecast
        anchors.top:ts1.bottom
        anchors.horizontalCenter:ts1.horizontalCenter
        topPadding:10
        spacing:50
        Repeater {
            id:r1
            model: 5
            Text {
                text:owm.forecastDays[index+1]
                color:Theme.viewTextColor
                font.pointSize:14
                font.bold:true
                antialiasing : true

                Image {
                    source:owm.forecastIcons[index+1]
                    width:48
                    height:48
                    smooth:true
                    anchors.top:parent.bottom
                    anchors.horizontalCenter:parent.horizontalCenter

                    Text {
                        text:owm.forecastRains[index+1]
                        color:Theme.viewTextColor
                        anchors.horizontalCenter:parent.horizontalCenter
                        anchors.top:parent.bottom
                        font.pointSize:12
                        antialiasing : true

                        Text {
                            text:owm.forecastTemps[index+1]
                            color:Theme.viewTextColor
                            anchors.horizontalCenter:parent.horizontalCenter
                            anchors.top:parent.bottom
                            font.pointSize:12
                            antialiasing : true
                        }
                    }
                }
            }
        }
    }

    Rectangle {
        id:ts2
        anchors.top:forecast.bottom
        implicitWidth: fullRepresentation.width*.95
        anchors.horizontalCenter:fullRepresentation.horizontalCenter
        anchors.topMargin:105
        radius:8
        implicitHeight: .5
        color: "#5b565d"
        antialiasing : true
        Layout.fillWidth: true
    }

    Column {
        id:radar_info
        anchors.top:ts2.bottom
        anchors.topMargin:10
        anchors.left:fullRepresentation.left
        spacing:2

        Image {
            id:radar
           // property string radarImg:"https://cdns.abclocal.go.com/three/ktrk/weather/16_9/SETX1_1280.jpg"
            source:owm.radarImage
            smooth: false // allow opacity mask == false
            width: fullRepresentation.width
            fillMode:Image.PreserveAspectFit
            visible: false
        }

        MouseArea {
            anchors.fill: radar
            acceptedButtons: Qt.LeftButton | Qt.MiddleButton
            hoverEnabled: true
            cursorShape:Qt.PointingHandCursor
            onClicked: {
                Qt.openUrlExternally("https://abc13.com/weather/")
            }
        }

        OpacityMask {
            anchors.fill: radar
            source: radar
            maskSource: Rectangle {    // whats behind mask is visible, adds rounded corners to radar image
                width: radar.width
                height: radar.height
                radius: 8
                antialiasing : true
                visible: false // this also needs to be invisible or it will cover up the image
            }
        }
    }
}
