import QtQuick 2.9
import org.kde.plasma.core 2.1
import org.kde.plasma.networkmanagement 0.2

Item {
   id:owm
   property var weatherData:{}
   property string weatherIcon:""
   property string currentTemp:""
   property string currentConditions:""
   property string lastUpdate:""
   property string alertText:""
   property string alertDesc:""
   property string weatherRealFeel:""
   property string weatherHumidity:""
   property string weatherWinds:""
   property string weatherSummary:""
   property string weatherSunrise:""
   property string weatherSunset:""
   property string weatherVisibility:""
   property bool weatherWarnings:false
   property var forecastDays:[]
   property var forecastIcons:[]
   property var forecastRains:[]
   property var forecastTemps:[]
   property string radarImage:"SETX1_1280.jpg"
   property string url1:"https://api.openweathermap.org/data/2.5/onecall?lat=29.668&lon=-95.069&units=imperial&exclude=hourly,minutely&appid=12334567890"
   //property string url1:"/home/Data/projects/QML/weather/OpenWeather/onecall.json"

   function getWeather(url){  // read weather icon code from file
      var xhr = new XMLHttpRequest();
      xhr.open("GET", url,false); // set Method and File
      xhr.onreadystatechange = function () {
         if(xhr.readyState === XMLHttpRequest.DONE){ // if request_status == DONE
            var response = xhr.responseText;
            weatherData = JSON.parse(response);
            response=null;
            xhr=null;
         }
      }
      xhr.send(); // begin the request
      processWeatherData();
   }


   function processWeatherData() {

      if (typeof (weatherData.current.dt) != undefined) {
         var d1=[];
         var i1=[];
         var r1=[];
         var t1=[];
         lastUpdate=Qt.formatTime(new Date(weatherData.current.dt*1000),"h:mm ap");
         currentTemp=Math.round(weatherData.current.temp)+"°"
         weatherSunrise=Qt.formatTime(new Date(weatherData.current.sunrise*1000),"h:mm ap");
         weatherSunset=Qt.formatTime(new Date(weatherData.current.sunset*1000),"h:mm ap")
         weatherVisibility=weatherData.current.visibility/1000+"mi"
         weatherIcon=weatherData.current.weather[0].icon
         weatherWarnings=weatherData.hasOwnProperty("alerts"); //? true:false // check if alert exists
         alertText=weatherWarnings ? "⚠ "+weatherData.alerts[0].event : ""
         alertDesc=weatherWarnings ? weatherData.alerts[0].description : ""
         currentConditions=Math.round(weatherData.current.temp)+"°  "+ cloudDescription()
         weatherRealFeel="Real Feel:  "+Math.round(weatherData.current.feels_like)+"°"
         weatherHumidity="     R/H:  "+weatherData.current.humidity+"%"
         weatherWinds="        Winds:  "+degToCompass(weatherData.current.wind_deg)+"  at "+Math.round(weatherData.current.wind_speed)
         weatherSummary=weatherRealFeel+weatherHumidity+weatherWinds

         for (var i = 0; i < Object.keys(weatherData.daily).length; i++) {
            d1[i]=Qt.formatDate(new Date(weatherData.daily[i].dt*1000),"ddd")
            //i1[i]=weatherData.daily[i].weather[0].icon
            i1[i]="../icons/"+weatherData.daily[i].weather[0].icon+".png";
            r1[i]=Math.ceil((weatherData.daily[i].pop*100)/5)*5+"%"
            //          Math.round(x/5)*5
            t1[i]=Math.round(weatherData.daily[i].temp.min)+"°"+" | "+Math.round(weatherData.daily[i].temp.max)+"°"
         }
         forecastDays=d1;
         forecastIcons=i1;
         forecastRains=r1;
         forecastTemps=t1;
         d1=null;
         i1=null;
         r1=null;
         t1=null;
      }
      weatherData=null;
      return null;
   }


   function degToCompass(num) {
      var val = Math.floor((num / 22.5) + 0.5);
      var arr = ["N", "NNE", "NE", "ENE", "E", "ESE", "SE", "SSE", "S", "SSW", "SW", "WSW", "W", "WNW", "NW", "NNW"];
      return arr[(val % 16)];
   }

   property var iconCode: {
      '01d': '\uf00d',
      '01n': '\uf02e',
      '02d': '\uf00c',
      '02n': '\uf083',
      '03n': '\uf031',
      '03d': '\uf013',
      '04n': '\uf031',
      '04d': '\uf013',
      '09d': '\uf009',
      '09n': '\uf037',
      '10d': '\uf00e',
      '10n': '\uf03a',
      '11d': '\uf01e',
      '11n': '\uf01e',
      '50d': '\uf014'}

      function formatSpeed() {
         if (unitsOfMeasure ==="metric") {
            return " m/s"
         } else {
            return " mph"
         }
      }
      function formatPressure(pressure) {
         if (cfg_pressure == 1) {
            return Math.round(pressure * 0.75006168282261) + i18n("mmHg")
         } else {
            return pressure + i18n("hPa")
         }
      }

      property var timerUpdateWeather:Timer {                  // timer to trigger update for weather info
         id: updateWeather
         interval: 20 * 60 * 1000 // every 20 minutes
         // interval:updateInterval
         running: true
         repeat:  true
         triggeredOnStart:true
         onTriggered: {
            getWeather(url1);
            radarImage="SETX1_1280.jpg";
            radarImage="https://cdns.abclocal.go.com/three/ktrk/weather/16_9/SETX1_1280.jpg";
            //startTime=0;
         }
      }

      property var suspendTimer:Timer{                  // timer to trigger update after wake from suspend mode
         id: suspend
         interval: 20*1000 ///delay 20 secs for suspend to resume
         running: false
         repeat:  false
         onTriggered: {
            getWeather(url1);
            radarImage="SETX1_1280.jpg";
            radarImage="https://cdns.abclocal.go.com/three/ktrk/weather/16_9/SETX1_1280.jpg";
            updateWeather.restart();
         }
      }

      NetworkStatus {   // check if network changed for resume from sleep mode...
         id: networkStatus       // systemctl suspend to test
         onNetworkStatusChanged: suspendTimer.start();
      }


      function cloudDescription() {
         switch(weatherData.current.weather[0].description) {
            case "broken clouds":
               return "Partly Cloudy"
            case "clouds":
               return "Partly Cloudy"
            case "few clouds":
               return "Partly Cloudy"
            case "light intensity drizzle":
               return "Drizzly Rain"
            case "heavy intensity drizzle":
               return "Drizzly Rain"
            case "light intensity drizzle rain":
               return "Drizzly Rain"
            case "heavy intensity drizzle rain":
               return "Drizzly Rain"
            case "light intensity drizzle rain":
               return "Drizzly Rain"
            case "heavy intensity drizzle rain":
               return "Drizzly Rain"
            case "heavy shower rain and drizzle":
               return "Drizzly Rain"
            case "light intensity shower rain":
               return "Light Rain Showers"
            case "heavy intensity shower rain":
               return "Heavy Rain Showers"
            case "ragged shower rain":
               return "Heavy Rain Showers"
            case "thunderstorm with light rain":
               return "Thunderstorms with light rain"
            case "thunderstorm with light rain":
               return "Thunderstorms with light drizzle"
            case "thunderstorm with drizzle":
               return "Thunderstorms with light drizzle"
            case "ragged thunderstorm":
               return "Heavy Thunderstorms"
            case "light thunderstorm":
               return "Light Rain Thunderstorms"
            case "heavy thunderstorm":
               return "Heavy Rain Tthunderstorms"
            case "thunderstorm":
               return "Thunderstorms"
            case "overcast clouds":
               return "Mostly Cloudy"
            case "scattered clouds":
               return "Partly Cloudy"
            case "haze":
               return "Hazey"
            case "sand/ dust whirls ":
               return "Dust"
            case "overcast clouds":
               return "Overcast"
            default:
               return weatherData.current.weather[0].description;
         }
      }
}
